summaryrefslogtreecommitdiff
path: root/src/lib/subtitle_decoder.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/subtitle_decoder.cc')
-rw-r--r--src/lib/subtitle_decoder.cc8
1 files changed, 3 insertions, 5 deletions
diff --git a/src/lib/subtitle_decoder.cc b/src/lib/subtitle_decoder.cc
index 0ffe5e501..c06f3d718 100644
--- a/src/lib/subtitle_decoder.cc
+++ b/src/lib/subtitle_decoder.cc
@@ -19,7 +19,6 @@
#include <boost/shared_ptr.hpp>
#include "subtitle_decoder.h"
-#include "subtitle.h"
using boost::shared_ptr;
@@ -31,11 +30,10 @@ SubtitleDecoder::SubtitleDecoder (shared_ptr<const Film> f)
/** Called by subclasses when a subtitle is ready.
* s may be 0 to say that there is no current subtitle.
* @param s New current subtitle, or 0.
*/
void
-SubtitleDecoder::subtitle (shared_ptr<TimedSubtitle> s)
+SubtitleDecoder::subtitle (shared_ptr<Image> image, dcpomatic::Rect<double> rect, Time from, Time to)
{
- Subtitle (s);
+ Subtitle (image, rect, from, to);
}
@@ -31,11 +30,10 @@ SubtitleDecoder::SubtitleDecoder (shared_ptr<const Film> f)
/** Called by subclasses when a subtitle is ready.
- * s may be 0 to say that there is no current subtitle.
- * @param s New current subtitle, or 0.
+ * Image may be 0 to say that there is no current subtitle.
*/
void